pitchtools.list_numbered_chromatic_pitch_classes_in_expr
========================================================

.. autofunction:: abjad.tools.pitchtools.list_numbered_chromatic_pitch_classes_in_expr.list_numbered_chromatic_pitch_classes_in_expr
